
How to help the project?
========================


Glad to see you're interested in helping out the project!

Generally, you can `ping riot <mailto:riot@c-base.org>`__ if you want to help out and don't exactly know where to start.

Here, we list a few possible opportunities where you can help us and become part of the driving community:


Communication
-------------

People need to be more aware of this project as it may be of great value to them.
If you're interested in spreading the word and getting people involved, you're very welcome to do so.
Again, please `ping riot <mailto:riot@c-base.org>`__ to get crucial info on how to do so.


Testing
-------

There are various degrees to which you can test the project:

  - Check the installation processes if they actually work on your platform and everything installs smoothly
  - Test-drive your installation or the `demo instance <https://demo.hackerfleet.de>`__ (Currently offline for maintenance)
  - Build and extend parts of the automatic testing infrastructure
  - Optimize and extend the continuous integration infrastructure

User Experience
---------------

We'd value your input on some very important user experience questions:

  - Is the current design logical and does it allow for a smooth user experience?
  - Check the supplied modules and the framework itself for consistency and good UX practices
  - Develop further use cases and user stories to spark new modules

Documentation
-------------

A lot of documentation is still missing. If you're interested in writing documentation, you should be familiar
with the two core tools we use for generating our documentation:

  - `reStructured Text formatting <http://www.sphinx-doc.org/en/stable/rest.html>`__
  - `Sphinx <http://www.sphinx-doc.org/en/stable/index.html>`__

We still need a lot of module, core framework and source code documentation, so there's ample opportunities in
this field.


Translations
------------

Most of (if not all) parts of the project can be translated and are waiting for your help.
You can use `Transifex <https://www.transifex.com/hackerfleet-community/isomer/>`__ to translate all the strings
we have or work with your favourite PO Editor. Have a look at :ref:`translating` for more details.


Developer Guidelines
====================

This is the rather dry material for new software developers:

.. toctree::
       :maxdepth: 2

       introduction
       contributing
       environment
       processes
       standards
       translating


Module documentation
--------------------

.. toctree::
      :glob:

      packages/*
